function c=and_re(a,b,r)
%       AND_RE(A,B,R) Restricted intersection defined as:
%
%       AND_RE(A,B,R) =
%
%               AND_PR(A,B) - R*(AND_ZA(A,B)-AND_PR(A,B)) for R >= 0
%
%               AND_PR(A,B) - R*(AND_PR(A,B)-AND_LU(A,B)) for R <  0
%
%       R(A,B) = 1 when A and B are strongly positively associated
%       R(A,B) =-1 when A and B are strongly negatively associated
%       R(A,B) = 0 when A and B are independent
%
%       If A and B are both row or column vectors, then C
%       is also a row or column vector. If A is a column vector
%       and B a row vector, then a matrix C is returned,
%       representing the Cartesian product A * B, where * is
%       AND_RE(Ax,Bx).
%
%       C = AND_RE(A,r) calculates intersection of all rows in A.
%
%       See also AND, AND_ZA, AND_LU, AND_PR.

% (c) Robert Babuska, March 1993

[am,an] = size(a);
if nargin == 3,
  [bm,bn] = size(b);
  if ( am > 1 & an == 1 & bn > 1 )
    a = a * ones(1,bn);
    if ( bm == 1 )
        b = ones(am,1) * b;
    end;
  end;
  c = a.*b;
  if (r >= 0)
    c = c + r*(min(a,b) - c);
  else
    c = c + r*(c - max(0,a+b-1));
  end;
else
  c = a(1,:);
  for i = 2 : am,
    d = a(i,:).*c;
    if (b >= 0)
      c = d + b*(min(a(i,:),c) - d);
    else
      c = d + b*(d - max(0,a(i,:)+c-1));
    end;
  end;
end;

