% Fuzzy control demonstration.

% (c) Robert Babuska, March 1994

echo off
% Reset things before we get started.
clear;clc;clf;
format 
figure(1); clf;
echo on

% This demo shows the use of functions TXT2RLS and INFER for
% the design of a fuzzy controller. A simple rule-base SAMPLE.RB
% is used as an example.

% Press any key to continue...
pause; 
clc
% Let us plot the rules:

more(10); more on;
type sample.rb
more off;

% Press any key to continue...
pause; 
clc
% The five rules are chosen such that the resulting fuzzy controller
% will mimic a linear PD controller. Let us compile the rule-base.

[rls,mfs,inputs,outputs,nlab,labels] = txt2rls('sample.rb');

% Press any key to continue...
pause; 
clc
% Matrix rls now contains the coded rule-base.

disp(rls)

% Press any key to continue...
pause; 
clc
% Matrix mfs contains the definitions of membership functions of all the
% fuzzy sets used in the rule-base.

disp(mfs)

% Press any key to continue...
pause; 
clc
% Text matrices inputs and outputs contain the input and output labels.

disp(inputs)

disp(outputs)

% Press any key to continue...
pause; 
clc
% Matrix nlab defines, how many labels were defined in the rule-base in
% each premise and consequent variable.

disp(nlab)

% Press any key to continue...
pause; 
clc
% Finally, text matrix labels contains all the fuzzy sets labels.

disp(labels)

% Press any key to continue...
pause; 
clc
% Now, let us calculate and plot the control surface of the controller.
% First we define a common domain for both controller inputs.

dom = -1.5:0.1:1.5;

% Then we use the MESHGRID function to create input matrices:

[x,y] = meshgrid(dom);

% Press any key to continue...
pause; 
clc
% The input vector for the INFER function contains all the input
% combinations in columns.

inp = [x(:) y(:)];

% Now we calculate the fuzzy controller output, using the rules and
% membership functions obtained from TXT2RLS:

z = y;
z(:) = infer(rls,mfs,inp);

% Press any key to continue...
pause; 
clc
% Let us plot the mesh and contour graphs of the control surface.

mesh(x,y,z); 

return

subplot(211); mesh(x,y,z); title('Control surface');
xlabel('error'); ylabel('error change'); zlabel('control input');

%subplot(212); contour(x,y,z); title('Control surface contours');
%xlabel('error'); ylabel('error change');

% To see the simulations with this simple fuzzy controller,
% choose "Simulink Demonstrations" and click the "Mamdani's 
% controller" icon.

% Press any key to stop...
pause; 
echo off; clc
