function [ret,x0,str,ts,xts]=mamdani(t,x,u,flag);
%MAMDANI	is the M-file description of the SIMULINK system named MAMDANI.
%	The block-diagram can be displayed by typing: MAMDANI.
%
%	SYS=MAMDANI(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes MAMDANI to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling MAMDANI with a FLAG of zero:
%	[SIZES]=MAMDANI([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[553,352,1001,673])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-23')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '20')
set_param(sys,'Min step size', '0.1')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Rules editor'.

new_system([sys,'/','Rules editor'])
set_param([sys,'/','Rules editor'],'Location',[4,380,131,533])
set_param([sys,'/','Rules editor'],...
		'Mask Display','Edit rules',...
		'Mask Type','Rule-base editor')
set_param([sys,'/','Rules editor'],...
		'Mask Dialogue','eval([''!notepad '' get_param ''.rb'']); eval([''[rls, initmfs, inputs, outputs, nlab, labels] = txt2rls('''''' get_param ''''''); if exist(''''mfs'''')~=1, mfs = initmfs; elseif length(mfs) == 0, mfs = initmfs; end;'']);')


%     Finished composite block 'Rules editor'.

set_param([sys,'/','Rules editor'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[10,9,75,40])


%     Subsystem  'LIst rules'.

new_system([sys,'/','LIst rules'])
set_param([sys,'/','LIst rules'],'Location',[-10,380,117,533])
set_param([sys,'/','LIst rules'],...
		'Mask Display','LIst rules',...
		'Mask Type',' ',...
		'Mask Dialogue','eval(''disp(rls2txt(rls, mfs, inputs, outputs, nlab, labels));'');')


%     Finished composite block 'LIst rules'.

set_param([sys,'/','LIst rules'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[10,49,75,85])


%     Subsystem  'Load data'.

new_system([sys,'/','Load data'])
set_param([sys,'/','Load data'],'Location',[4,380,131,533])
set_param([sys,'/','Load data'],...
		'Mask Display','Load',...
		'Mask Type',' ',...
		'Mask Dialogue','eval([''load '' get_param]);')


%     Finished composite block 'Load data'.

set_param([sys,'/','Load data'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[195,9,250,40])


%     Subsystem  'Save data'.

new_system([sys,'/','Save data'])
set_param([sys,'/','Save data'],'Location',[4,380,131,533])
set_param([sys,'/','Save data'],...
		'Mask Display','Save',...
		'Mask Type',' ',...
		'Mask Dialogue','eval([''save '' get_param]); ')


%     Finished composite block 'Save data'.

set_param([sys,'/','Save data'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[195,59,250,90])


%     Subsystem  'LUT mesh'.

new_system([sys,'/','LUT mesh'])
set_param([sys,'/','LUT mesh'],'Location',[-10,380,117,533])
set_param([sys,'/','LUT mesh'],...
		'Mask Display','Mesh',...
		'Mask Type',' ')
set_param([sys,'/','LUT mesh'],...
		'Mask Dialogue','eval(''dom = -1:0.1:1; [x,y] = meshgrid(dom); x = [x(:) y(:)]; y(:) = infer(rls,mfs,x); clg; mesh(dom,dom,y); xlabel(''''Error'''');ylabel(''''Output change''''); zlabel(''''Control input''''); drawnow;'');')


%     Finished composite block 'LUT mesh'.

set_param([sys,'/','LUT mesh'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[265,9,325,40])


%     Subsystem  'LUT contour'.

new_system([sys,'/','LUT contour'])
set_param([sys,'/','LUT contour'],'Location',[-10,380,117,533])
set_param([sys,'/','LUT contour'],...
		'Mask Display','Contour',...
		'Mask Type',' ')
set_param([sys,'/','LUT contour'],...
		'Mask Dialogue','eval(''dom = -1:0.1:1; [x,y] = meshgrid(dom); x = [x(:) y(:)]; y(:) = infer(rls,mfs,x); clg; contour(dom,dom,y,30); xlabel(''''Error'''');ylabel(''''Output change'''');'');')


%     Finished composite block 'LUT contour'.

set_param([sys,'/','LUT contour'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[265,59,325,90])


%     Subsystem  'Rules editor1'.

new_system([sys,'/','Rules editor1'])
set_param([sys,'/','Rules editor1'],'Location',[4,380,131,533])
set_param([sys,'/','Rules editor1'],...
		'Mask Display','Compile \n rule-base',...
		'Mask Type','Rule-base editor')
set_param([sys,'/','Rules editor1'],...
		'Mask Dialogue','eval([''[rls, initmfs, inputs, outputs, nlab, labels] = txt2rls('''''' get_param ''''''); if exist(''''mfs'''')~=1, mfs = initmfs; elseif length(mfs) == 0, mfs = initmfs; end;'']);')


%     Finished composite block 'Rules editor1'.

set_param([sys,'/','Rules editor1'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[340,4,415,50])


%     Subsystem  'More Info'.

new_system([sys,'/','More Info'])
set_param([sys,'/','More Info'],'Location',[489,103,877,287])

add_block('built-in/Note',[sys,'/',['More Info/This demonstration compares PD vers. Fuzzy control',13,'for a nonlinear third-order plant.  ']])
set_param([sys,'/',['More Info/This demonstration compares PD vers. Fuzzy control',13,'for a nonlinear third-order plant.  ']],...
		'position',[190,10,195,15])

add_block('built-in/Note',[sys,'/',['More Info/To strart click on "Compile rule-base" first. ',13,'On other systems than MS-Windows, you may want ',13,'to change the "Edit rules" icon in order to set your',13,'preferred text editor. Experiment with changing',13,'membership functions and rules.']])
set_param([sys,'/',['More Info/To strart click on "Compile rule-base" first. ',13,'On other systems than MS-Windows, you may want ',13,'to change the "Edit rules" icon in order to set your',13,'preferred text editor. Experiment with changing',13,'membership functions and rules.']],...
		'position',[188,55,193,60])
set_param([sys,'/','More Info'],...
		'Mask Display','Help')


%     Finished composite block 'More Info'.

set_param([sys,'/','More Info'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[345,65,415,90])


%     Subsystem  'Update MFs1'.

new_system([sys,'/','Update MFs1'])
set_param([sys,'/','Update MFs1'],'Location',[-10,380,117,533])
set_param([sys,'/','Update MFs1'],...
		'Mask Display','Update \n output MFs',...
		'Mask Type',' ')
set_param([sys,'/','Update MFs1'],...
		'Mask Dialogue','eval(''if mfget(3)==[], mfset(3, ''''mfs'''',mfs(7:9,:),''''domain'''',''''-10:0.5:10'''',''''position'''',[ 4    88   500   293]); else mfs(7:9,:) = mfget(3); end; set(3, ''''NumberTitle'''',''''off'''',''''Name'''',''''Control input'''');'');')


%     Finished composite block 'Update MFs1'.

set_param([sys,'/','Update MFs1'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[95,54,175,90])


%     Subsystem  'Update MFs'.

new_system([sys,'/','Update MFs'])
set_param([sys,'/','Update MFs'],'Location',[-10,380,117,533])
set_param([sys,'/','Update MFs'],...
		'Mask Display','Update \n input MFs',...
		'Mask Type',' ')
set_param([sys,'/','Update MFs'],...
		'Mask Dialogue','eval(''if mfget(1)==[], mfset(1,''''mfs'''',mfs(1:3,:),''''position'''',[  2 431 500 293]); else mfs(1:3,:) = mfget(1); end; set(1, ''''NumberTitle'''',''''off'''',''''Name'''',''''Error'''');''); eval(''if mfget(2)==[], mfset(2,''''mfs'''',mfs(4:6,:),''''position'''',[502 431 500 293]); else mfs(4:6,:) = mfget(2); end; set(2, ''''NumberTitle'''',''''off'''',''''Name'''',''''Output change'''');'');')


%     Finished composite block 'Update MFs'.

set_param([sys,'/','Update MFs'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[95,9,175,45])


%     Subsystem  'Green'.

new_system([sys,'/','Green'])
set_param([sys,'/','Green'],'Location',[4,68,278,261])

add_block('built-in/Inport',[sys,'/','Green/x'])
set_param([sys,'/','Green/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Green/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Green/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunplot',...
		'parameters','figno,ax, color',...
		'position',[130,55,180,75])
add_line([sys,'/','Green'],[90,65;125,65])
set_param([sys,'/','Green'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Green'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter figure, plotting ranges and line type.|Figure:|Time range:|y-min:|y-max:|Line type (rgbw-:*):')
set_param([sys,'/','Green'],...
		'Mask Translate','figno = @1; color = @5; ax = [0, @2, @3, @4];')
set_param([sys,'/','Green'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works.',...
		'Mask Entries','4\/20\/-2\/2\/''g-''\/')


%     Finished composite block 'Green'.

set_param([sys,'/','Green'],...
		'Drop Shadow',4,...
		'position',[315,126,345,164])


%     Subsystem  ' Plant  '.

new_system([sys,'/',' Plant  '])
set_param([sys,'/',' Plant  '],'Location',[395,402,871,515])

add_block('built-in/Outport',[sys,'/',' Plant  /out_1'])
set_param([sys,'/',' Plant  /out_1'],...
		'position',[445,25,465,45])

add_block('built-in/Gain',[sys,'/',' Plant  /K1'])
set_param([sys,'/',' Plant  /K1'],...
		'position',[315,17,345,53])

add_block('built-in/Integrator',[sys,'/',' Plant  /Integrator2'])
set_param([sys,'/',' Plant  /Integrator2'],...
		'hide name',0,...
		'position',[400,10,430,60])

add_block('built-in/Gain',[sys,'/',' Plant  /1//T'])
set_param([sys,'/',' Plant  /1//T'],...
		'Gain','15',...
		'position',[215,15,250,55])

add_block('built-in/Integrator',[sys,'/',' Plant  /Integrator'])
set_param([sys,'/',' Plant  /Integrator'],...
		'hide name',0,...
		'position',[265,10,295,60])

add_block('built-in/Sum',[sys,'/',' Plant  /Sum1'])
set_param([sys,'/',' Plant  /Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[165,25,190,60])

add_block('built-in/Integrator',[sys,'/',' Plant  /Integrator1'])
set_param([sys,'/',' Plant  /Integrator1'],...
		'hide name',0,...
		'position',[360,10,390,60])

add_block('built-in/Saturation',[sys,'/',' Plant  /Saturation1'])
set_param([sys,'/',' Plant  /Saturation1'],...
		'hide name',0,...
		'Lower Limit','-1',...
		'Upper Limit','1',...
		'position',[120,16,145,54])

add_block('built-in/Dead Zone',[sys,'/',' Plant  /Dead Zone1'])
set_param([sys,'/',' Plant  /Dead Zone1'],...
		'hide name',0,...
		'Lower_value','-0.1',...
		'Upper_value','0.1',...
		'position',[55,18,95,52])

add_block('built-in/Inport',[sys,'/',' Plant  /in_1'])
set_param([sys,'/',' Plant  /in_1'],...
		'position',[15,25,35,45])
add_line([sys,'/',' Plant  '],[150,35;160,35])
add_line([sys,'/',' Plant  '],[100,35;115,35])
add_line([sys,'/',' Plant  '],[40,35;50,35])
add_line([sys,'/',' Plant  '],[435,35;440,35])
add_line([sys,'/',' Plant  '],[350,35;355,35])
add_line([sys,'/',' Plant  '],[300,35;310,35])
add_line([sys,'/',' Plant  '],[395,35;395,35])
add_line([sys,'/',' Plant  '],[255,35;260,35])
add_line([sys,'/',' Plant  '],[195,45;210,35])
add_line([sys,'/',' Plant  '],[300,35;300,80;150,80;160,50])


%     Finished composite block ' Plant  '.

set_param([sys,'/',' Plant  '],...
		'position',[245,120,275,170])


%     Subsystem  'PD'.

new_system([sys,'/','PD'])
set_param([sys,'/','PD'],'Location',[4,85,349,298])

add_block('built-in/Gain',[sys,'/','PD/D'])
set_param([sys,'/','PD/D'],...
		'Gain','D',...
		'position',[85,129,115,171])

add_block('built-in/Derivative',[sys,'/','PD/Derivative'])
set_param([sys,'/','PD/Derivative'],...
		'position',[145,138,185,162])

add_block('built-in/Inport',[sys,'/','PD/In_2'])
set_param([sys,'/','PD/In_2'],...
		'Port','2',...
		'position',[25,140,45,160])

add_block('built-in/Inport',[sys,'/','PD/In_1'])
set_param([sys,'/','PD/In_1'],...
		'position',[25,70,45,90])

add_block('built-in/Outport',[sys,'/','PD/Out_1'])
set_param([sys,'/','PD/Out_1'],...
		'position',[290,70,310,90])

add_block('built-in/Transfer Fcn',[sys,'/','PD/Integral'])
set_param([sys,'/','PD/Integral'],...
		'Numerator','I',...
		'Denominator','[1 0]',...
		'position',[110,62,145,98])

add_block('built-in/Gain',[sys,'/','PD/Proportional'])
set_param([sys,'/','PD/Proportional'],...
		'Gain','P',...
		'position',[120,16,155,44])

add_block('built-in/Sum',[sys,'/','PD/Sum'])
set_param([sys,'/','PD/Sum'],...
		'inputs','+++',...
		'position',[245,62,265,98])
add_line([sys,'/','PD'],[50,150;80,150])
add_line([sys,'/','PD'],[160,30;210,30;210,70;240,70])
add_line([sys,'/','PD'],[150,80;240,80])
add_line([sys,'/','PD'],[190,150;240,90])
add_line([sys,'/','PD'],[50,80;105,80])
add_line([sys,'/','PD'],[80,80;80,30;115,30])
add_line([sys,'/','PD'],[270,80;285,80])
add_line([sys,'/','PD'],[120,150;140,150])
set_param([sys,'/','PD'],...
		'Mask Display','PD',...
		'Mask Dialogue','PID controller |Proportional gain: |Derivative gain: |Integral gain:',...
		'Mask Translate','P = @1; D = -@2; I = @3;',...
		'Mask Entries','20\/16\/0\/')


%     Finished composite block 'PD'.

set_param([sys,'/','PD'],...
		'position',[160,125,200,165])

add_block('built-in/Sum',[sys,'/','Sum4'])
set_param([sys,'/','Sum4'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[95,115,120,150])

add_block('built-in/Signal Generator',[sys,'/','Signal'])
set_param([sys,'/','Signal'],...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','0.500000',...
		'Freq Range','5.000000',...
		'Wave','Sqr',...
		'Units','Rads',...
		'position',[15,108,60,142])


%     Subsystem  'Red'.

new_system([sys,'/','Red'])
set_param([sys,'/','Red'],'Location',[4,68,278,261])

add_block('built-in/Inport',[sys,'/','Red/x'])
set_param([sys,'/','Red/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Red/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Red/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunplot',...
		'parameters','figno,ax, color',...
		'position',[130,55,180,75])
add_line([sys,'/','Red'],[90,65;125,65])
set_param([sys,'/','Red'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Red'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter figure, plotting ranges and line type.|Figure:|Time range:|y-min:|y-max:|Line type (rgbw-:*):')
set_param([sys,'/','Red'],...
		'Mask Translate','figno = @1; color = @5; ax = [0, @2, @3, @4];')
set_param([sys,'/','Red'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works.',...
		'Mask Entries','4\/20\/-2\/2\/''r-''\/')


%     Finished composite block 'Red'.

set_param([sys,'/','Red'],...
		'orientation',2,...
		'Drop Shadow',4,...
		'position',[15,171,45,209])

add_block('built-in/Sum',[sys,'/','Sum3'])
set_param([sys,'/','Sum3'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[90,215,115,250])


%     Subsystem  ' Plant '.

new_system([sys,'/',' Plant '])
set_param([sys,'/',' Plant '],'Location',[224,135,844,361])

add_block('built-in/Outport',[sys,'/',' Plant /out_1'])
set_param([sys,'/',' Plant /out_1'],...
		'position',[490,75,510,95])

add_block('built-in/Gain',[sys,'/',' Plant /K1'])
set_param([sys,'/',' Plant /K1'],...
		'position',[360,67,390,103])

add_block('built-in/Integrator',[sys,'/',' Plant /Integrator2'])
set_param([sys,'/',' Plant /Integrator2'],...
		'hide name',0,...
		'position',[445,60,475,110])

add_block('built-in/Gain',[sys,'/',' Plant /1//T'])
set_param([sys,'/',' Plant /1//T'],...
		'Gain','15',...
		'position',[260,65,295,105])

add_block('built-in/Integrator',[sys,'/',' Plant /Integrator'])
set_param([sys,'/',' Plant /Integrator'],...
		'hide name',0,...
		'position',[310,60,340,110])

add_block('built-in/Sum',[sys,'/',' Plant /Sum1'])
set_param([sys,'/',' Plant /Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[210,75,235,110])

add_block('built-in/Integrator',[sys,'/',' Plant /Integrator1'])
set_param([sys,'/',' Plant /Integrator1'],...
		'hide name',0,...
		'position',[405,60,435,110])

add_block('built-in/Saturation',[sys,'/',' Plant /Saturation1'])
set_param([sys,'/',' Plant /Saturation1'],...
		'hide name',0,...
		'Lower Limit','-1',...
		'Upper Limit','1',...
		'position',[165,66,190,104])

add_block('built-in/Dead Zone',[sys,'/',' Plant /Dead Zone1'])
set_param([sys,'/',' Plant /Dead Zone1'],...
		'hide name',0,...
		'Lower_value','-0.1',...
		'Upper_value','0.1',...
		'position',[100,68,140,102])

add_block('built-in/Inport',[sys,'/',' Plant /in_1'])
set_param([sys,'/',' Plant /in_1'],...
		'position',[60,75,80,95])
add_line([sys,'/',' Plant '],[345,85;345,130;200,130;205,100])
add_line([sys,'/',' Plant '],[240,95;255,85])
add_line([sys,'/',' Plant '],[300,85;305,85])
add_line([sys,'/',' Plant '],[440,85;440,85])
add_line([sys,'/',' Plant '],[345,85;355,85])
add_line([sys,'/',' Plant '],[395,85;400,85])
add_line([sys,'/',' Plant '],[480,85;485,85])
add_line([sys,'/',' Plant '],[85,85;95,85])
add_line([sys,'/',' Plant '],[145,85;160,85])
add_line([sys,'/',' Plant '],[195,85;205,85])


%     Finished composite block ' Plant '.

set_param([sys,'/',' Plant '],...
		'position',[300,220,330,270])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[175,225,200,260])

add_block('built-in/Saturation',[sys,'/','Saturation1'])
set_param([sys,'/','Saturation1'],...
		'hide name',0,...
		'Lower Limit','-2',...
		'Upper Limit','2',...
		'position',[130,225,155,245])

add_block('built-in/Gain',[sys,'/','K4'])
set_param([sys,'/','K4'],...
		'hide name',0,...
		'Gain','-1',...
		'position',[30,268,50,292])

add_block('built-in/Derivative',[sys,'/','Derivative'])
set_param([sys,'/','Derivative'],...
		'hide name',0,...
		'position',[70,270,100,290])

add_block('built-in/Saturation',[sys,'/','Saturation2'])
set_param([sys,'/','Saturation2'],...
		'hide name',0,...
		'Lower Limit','-2',...
		'Upper Limit','2',...
		'position',[120,270,145,290])


%     Subsystem  'White'.

new_system([sys,'/','White'])
set_param([sys,'/','White'],'Location',[4,68,278,261])

add_block('built-in/S-Function',[sys,'/',['White/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['White/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunplot',...
		'parameters','figno,ax, color',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','White/x'])
set_param([sys,'/','White/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','White'],[90,65;125,65])
set_param([sys,'/','White'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','White'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter figure, plotting ranges and line type.|Figure:|Time range:|y-min:|y-max:|Line type (rgbw-:*):')
set_param([sys,'/','White'],...
		'Mask Translate','figno = @1; color = @5; ax = [0, @2, @3, @4];')
set_param([sys,'/','White'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works.',...
		'Mask Entries','4\/20\/-2\/2\/''w-''\/')


%     Finished composite block 'White'.

set_param([sys,'/','White'],...
		'Drop Shadow',4,...
		'position',[375,226,405,264])

add_block('built-in/S-Function',[sys,'/','FLC'])
set_param([sys,'/','FLC'],...
		'function name','sfuninf',...
		'parameters','rls, mfs, def',...
		'Mask Display','FLC',...
		'Mask Type','Fuzzy inference block')
set_param([sys,'/','FLC'],...
		'Mask Dialogue','MIN-MAX inference with \n fuzzy means defuzzification|Rule matrix: |Membership functions matrix: |Default output:',...
		'Mask Translate','rls = @1; mfs = @2; def = @3;')
set_param([sys,'/','FLC'],...
		'Mask Help','Fuzzy inference block can be used as a direct fuzzy controller or as a fuzzy supervisor. For details on dialog parameters see INFER.',...
		'Mask Entries','rls\/mfs\/0\/')
set_param([sys,'/','FLC'],...
		'position',[215,229,280,261])
add_line(sys,[280,145;310,145])
add_line(sys,[335,245;335,305;15,305;25,280])
add_line(sys,[55,280;65,280])
add_line(sys,[335,245;370,245])
add_line(sys,[285,245;295,245])
add_line(sys,[205,145;240,145])
add_line(sys,[205,245;210,245])
add_line(sys,[105,280;115,280])
add_line(sys,[120,235;125,235])
add_line(sys,[160,235;170,235])
add_line(sys,[150,280;155,280;155,250;170,250])
add_line(sys,[15,280;15,240;85,240])
add_line(sys,[65,125;90,125])
add_line(sys,[125,135;155,135])
add_line(sys,[290,145;290,190;140,190;140,155;155,155])
add_line(sys,[140,190;80,190;90,140])
add_line(sys,[65,125;65,225;85,225])
add_line(sys,[65,190;60,190;50,190])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
