function  [sys, x0]  = sfunbar(t,x,u,flag,figno,nbars,ymax,color)
%SFUNBAR S-function for a bar graph scope using graph window.
%
%	This M-file is designed to be used in a SIMULINK S-function block.
%
%       The input arguments are
%       figno:          Figure number.
%       nbars:          Number of bars (i.e. inputs).
%       ymax:           Maximum bar height.
%       color:          Bar color.

% (c) Robert Babuska, December 1993

if abs(flag) == 2   	% A real time hit 

        sys = x;
        [xx,yy] = bar(1:nbars,u);
        set(x,'ydata',yy);

elseif flag  == 0,      % Initialization

	% Return system sizes
        % 0 continuous states, 1 discrete state
        % 0 outputs, nbar inputs, 0 roots, no direct feed-through.
        sys = [0;1;0;nbars;0;1];

        while ~any(get(0,'Children')==figno),
          figure('Visible','off');
        end
        set(figno,'Visible','off');
        oldfig = get(0,'CurrentFigure');
        set(0,'CurrentFigure',figno);
        [xx,yy] = bar(1:nbars,zeros(nbars,1));
        clf;
        hold on;
        x0 = plot(xx,yy,color,'EraseMode','background');
        axis([min(xx) max(xx) 0 ymax]);
        hold off;
        set(figno,'Visible','on')
        set(0,'CurrentFigure',oldfig);
else
	% Other flag options not defined.
	sys = [];
end
