function  [sys, x0]  = sfundef(t,x,u,flag,figno,domain,def,par1,par2)
% SFUNDEF an S-function which defuzzifies a fuzzy set
%
%       This M-file is designed to be used in a SIMULINK S-function block.
%	
%       The input arguments are
%       figno:          Figure number (0 for no on-line plot).
%       domain:         Ouput domain.
%       def:            Defuzzification operator function (if [], default
%                       COA method is used).
%       par1:           First additional parameter ([] for non-parametric
%                       operators).
%       par2:           Second additional parameter ([] for non-parametric
%                       operators).

% (c) Robert Babuska, December 1993

if abs(flag) == 2                       % state
   sys = x;

elseif flag == 3                        % output
  if length(def) == 0,
      sys = coa(domain,u');
  elseif length(par1) == 0,
      sys = feval(def,domain,u');
  elseif length(par2) == 0,
      sys = feval(def,domain,u',par1);
  else
      sys = feval(def,domain,u',par1,par2);
  end;
  if figno ~= 0,
    if strcmp(par2,'singleton');
      ss = u;
      npoints = 3*length(domain);
      u = zeros(1,npoints);
      u(2:3:npoints) = ss;
    end;
    set(x(1),'ydata',u);
    set(x(2),'xdata',[sys sys]);
  end;

elseif flag  == 0,
  % [cont, discr, outputs, inputs, roots, feedthrough]
  npoints = length(domain);
  sys = [0, 2, 1, npoints, 0, 1];
  x0 = [0;0];
  if figno ~= 0,
        while ~any(get(0,'Children')==figno),
          figure('Visible','off');
        end
        set(figno,'Visible','off');
        oldfig = get(0,'CurrentFigure');
        set(0,'CurrentFigure',figno);
        clf;
        hold on;
        if strcmp(par2,'singleton'),    % singletons
          domain = ones(3,1)*domain; domain = domain(:)';
          x0(1) = ...
          plot(domain,zeros(1,3*npoints),'w','EraseMode','xor','LineWidth',5);
          x0(2) = plot([0 0],[0 1],'r','LineWidth',2,'EraseMode','xor');
        else
          x0(1) = plot(domain,zeros(size(domain)),'w','EraseMode','xor');
          x0(2) = plot([0 0],[0 1],'r','LineWidth',2,'EraseMode','xor');
        end;
        axis([min(domain) max(domain) 0 1]);
        hold off;
        set(gca,'Box','on');
        set(figno,'BackingStore','off','Visible','on')
        set(0,'CurrentFigure',oldfig);
  end;
else 
    sys = [];
end

