function [ret,x0,str]=simctrl(t,x,u,flag);
%SIMCTRL	is the M-file description of the SIMULINK system named SIMCTRL.
%	The block-diagram can be displayed by typing: SIMCTRL.
%
%	SYS=SIMCTRL(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SIMCTRL to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SIMCTRL with a FLAG of zero:
%	[SIZES]=SIMCTRL([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[416,351,1004,748])
     open_system(sys)
end;
set_param(sys,'algorithm',		'RK-45')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'1000')
set_param(sys,'Min step size',	'5')
set_param(sys,'Max step size',	'5')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','yc',...
		'position',[500,177,545,203])


%     Subsystem  'Graph Scope'.

new_system([sys,'/','Graph Scope'])
set_param([sys,'/','Graph Scope'],'Location',[0,0,274,193])

add_block('built-in/S-function',[sys,'/',['Graph Scope/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph Scope/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Graph Scope/x'])
set_param([sys,'/','Graph Scope/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Graph Scope'],[90,65;120,65])
set_param([sys,'/','Graph Scope'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph Scope'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*):',...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3];')
set_param([sys,'/','Graph Scope'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works.')
set_param([sys,'/','Graph Scope'],...
		'Mask Entries','1000\/1\/2.5\/''y-''\/')


%     Finished composite block 'Graph Scope'.

set_param([sys,'/','Graph Scope'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[505,121,535,159])


%     Subsystem  'Graph Scope1'.

new_system([sys,'/','Graph Scope1'])
set_param([sys,'/','Graph Scope1'],'Location',[0,0,274,193])

add_block('built-in/Inport',[sys,'/','Graph Scope1/x'])
set_param([sys,'/','Graph Scope1/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-function',[sys,'/',['Graph Scope1/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph Scope1/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color',...
		'position',[130,55,180,75])
add_line([sys,'/','Graph Scope1'],[90,65;120,65])
set_param([sys,'/','Graph Scope1'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph Scope1'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*):',...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3];')
set_param([sys,'/','Graph Scope1'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works.')
set_param([sys,'/','Graph Scope1'],...
		'Mask Entries','1000\/1\/2.5\/''r-''\/')


%     Finished composite block 'Graph Scope1'.

set_param([sys,'/','Graph Scope1'],...
		'orientation',2,...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[15,11,45,49])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'Vgain','100.000000',...
		'Hgain','1000.000000',...
		'Vmax','200.000000',...
		'Hmax','2000.000000',...
		'Window',[3,66,325,446],...
		'position',[405,62,425,88])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','uc',...
		'position',[385,12,430,38])

add_block('built-in/S-function',[sys,'/','Sugeno'])
set_param([sys,'/','Sugeno'],...
		'hide name',0,...
		'function name','sfunsug',...
		'parameters','rls, mfs, p, def',...
		'Mask Display','SUGENO',...
		'Mask Type','Sugeno''s fuzzy inference')
set_param([sys,'/','Sugeno'],...
		'Mask Dialogue','Sugeno-Takagi inference|Premise matrix: |Membership functions matrix: |Consequent parameters: |Default output:',...
		'Mask Translate','rls = @1; mfs = @2; p = @3; def = @4;',...
		'Mask Help','')
set_param([sys,'/','Sugeno'],...
		'Mask Entries','rli\/mfi\/pi\/50\/',...
		'position',[265,124,340,156])

add_block('built-in/Constant',[sys,'/','Setpoint - y1'])
set_param([sys,'/','Setpoint - y1'],...
		'orientation',2,...
		'hide name',0,...
		'position',[195,165,215,185])


%     Subsystem  'Plant'.

new_system([sys,'/','Plant'])
set_param([sys,'/','Plant'],'Location',[283,509,555,712])

add_block('built-in/Unit Delay',[sys,'/','Plant/Unit Delay1'])
set_param([sys,'/','Plant/Unit Delay1'],...
		'orientation',2,...
		'hide name',0,...
		'x0','1.2',...
		'Sample time','5',...
		'position',[85,88,110,112])

add_block('built-in/Unit Delay',[sys,'/','Plant/Unit Delay'])
set_param([sys,'/','Plant/Unit Delay'],...
		'orientation',2,...
		'hide name',0,...
		'x0','1.2',...
		'Sample time','5',...
		'position',[140,88,165,112])

add_block('built-in/S-function',[sys,'/','Plant/MLP1'])
set_param([sys,'/','Plant/MLP1'],...
		'hide name',0,...
		'function name','sfnnet',...
		'parameters','ts,nfun,wb1,wb2,wb3,ini',...
		'Mask Display','MLP',...
		'Mask Type','MLP')
set_param([sys,'/','Plant/MLP1'],...
		'Mask Dialogue','Multi-layered perceptron |Sample time: |Neuron functions: |First layer [W B]: |Second layer [W B]: |Third layer [W B]: | Initial condition:')
set_param([sys,'/','Plant/MLP1'],...
		'Mask Translate','ts = @1; nfun = @2; wb1 = @3;  wb2 = @4; wb3 = @5; ini = @6;',...
		'Mask Help','Multi-layered perceptron.',...
		'Mask Entries','5\/[''tansig '';''purelin'']\/[W1 B1]\/[W2 B2]\/[]\/1.2\/')
set_param([sys,'/','Plant/MLP1'],...
		'position',[120,55,170,75])

add_block('built-in/Mux',[sys,'/','Plant/Mux'])
set_param([sys,'/','Plant/Mux'],...
		'hide name',0,...
		'inputs','3',...
		'position',[80,47,105,83])

add_block('built-in/Inport',[sys,'/','Plant/in_1'])
set_param([sys,'/','Plant/in_1'],...
		'position',[15,45,35,65])

add_block('built-in/Outport',[sys,'/','Plant/out_1'])
set_param([sys,'/','Plant/out_1'],...
		'position',[215,55,235,75])
add_line([sys,'/','Plant'],[135,100;135,130;55,130;55,65;70,65])
add_line([sys,'/','Plant'],[80,100;65,100;65,75;70,75])
add_line([sys,'/','Plant'],[135,100;120,100])
add_line([sys,'/','Plant'],[175,65;205,65])
add_line([sys,'/','Plant'],[195,65;195,100;175,100])
add_line([sys,'/','Plant'],[110,65;110,65])
add_line([sys,'/','Plant'],[40,55;70,55])


%     Finished composite block 'Plant'.

set_param([sys,'/','Plant'],...
		'position',[380,115,410,165])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','5',...
		'position',[195,107,245,163])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'orientation',2,...
		'hide name',0,...
		'position',[135,35,165,70])

add_block('built-in/Constant',[sys,'/','Setpoint - y2'])
set_param([sys,'/','Setpoint - y2'],...
		'orientation',2,...
		'hide name',0,...
		'Value','1.2',...
		'position',[195,62,225,88])

add_block('built-in/Filter',[sys,'/','Filter'])
set_param([sys,'/','Filter'],...
		'orientation',2,...
		'Denominator','[1 -0.99]',...
		'Sample time','5',...
		'position',[90,211,135,249])

add_block('built-in/Constant',[sys,'/','Bias'])
set_param([sys,'/','Bias'],...
		'position',[200,295,220,315])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'hide name',0,...
		'inputs','5',...
		'position',[250,252,280,308])

add_block('built-in/S-function',[sys,'/','Sugeno1'])
set_param([sys,'/','Sugeno1'],...
		'function name','sfunsug',...
		'parameters','rls, mfs, p, def',...
		'Mask Display','SUGENO',...
		'Mask Type','Sugeno''s fuzzy inference')
set_param([sys,'/','Sugeno1'],...
		'Mask Dialogue','Sugeno-Takagi inference|Premise matrix: |Membership functions matrix: |Consequent parameters: |Default output:',...
		'Mask Translate','rls = @1; mfs = @2; p = @3; def = @4;')
set_param([sys,'/','Sugeno1'],...
		'Mask Help','',...
		'Mask Entries','rls\/mfs\/p\/1\/',...
		'position',[300,254,375,286])

add_block('built-in/Unit Delay',[sys,'/','Unit Delay1'])
set_param([sys,'/','Unit Delay1'],...
		'hide name',0,...
		'x0','1.1',...
		'Sample time','5',...
		'position',[390,256,425,284])

add_block('built-in/Sum',[sys,'/','Sum3'])
set_param([sys,'/','Sum3'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[470,245,500,280])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[105,105,135,140])

add_block('built-in/Signal Generator',[sys,'/','Signal Gen.1'])
set_param([sys,'/','Signal Gen.1'],...
		'orientation',2,...
		'Peak','0.250000',...
		'Peak Range','5.000000',...
		'Freq','0.010000',...
		'Freq Range','5.000000',...
		'Wave','Sin',...
		'Units','Rads')
open_system([sys,'/','Signal Gen.1'])
set_param([sys,'/','Signal Gen.1'],...
		'position',[230,13,275,47])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'mat-name','e',...
		'position',[75,282,120,308])


%     Subsystem  'Graph Scope2'.

new_system([sys,'/','Graph Scope2'])
set_param([sys,'/','Graph Scope2'],'Location',[0,0,274,193])

add_block('built-in/Inport',[sys,'/','Graph Scope2/x'])
set_param([sys,'/','Graph Scope2/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-function',[sys,'/',['Graph Scope2/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph Scope2/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color',...
		'position',[130,55,180,75])
add_line([sys,'/','Graph Scope2'],[90,65;120,65])
set_param([sys,'/','Graph Scope2'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph Scope2'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*):',...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3];')
set_param([sys,'/','Graph Scope2'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works.')
set_param([sys,'/','Graph Scope2'],...
		'Mask Entries','1000\/1\/2.5\/''g-''\/')


%     Finished composite block 'Graph Scope2'.

set_param([sys,'/','Graph Scope2'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[465,296,495,334])
add_line(sys,[415,140;495,140])
add_line(sys,[465,140;465,190;490,190])
add_line(sys,[345,140;370,140])
add_line(sys,[130,55;90,55;90,115;95,115])
add_line(sys,[90,55;90,30;55,30])
add_line(sys,[355,140;355,75;395,75])
add_line(sys,[355,75;355,25;375,25])
add_line(sys,[250,135;255,140])
add_line(sys,[140,125;185,125])
add_line(sys,[140,125;145,145;185,145])
add_line(sys,[190,175;175,175;175,155;185,155])
add_line(sys,[190,75;175,60])
add_line(sys,[430,270;460,270])
add_line(sys,[440,270;440,260;415,235;375,240;215,240;215,260;240,260])
add_line(sys,[215,260;215,280;240,280])
add_line(sys,[225,305;240,300])
add_line(sys,[285,280;290,270])
add_line(sys,[355,140;180,210;175,265;180,290;240,290])
add_line(sys,[176,270;240,270])
add_line(sys,[505,265;515,265;515,355;155,355;155,230;145,230])
add_line(sys,[380,270;380,270])
add_line(sys,[85,230;50,230;50,135;95,130])
add_line(sys,[50,230;50,295;65,295])
add_line(sys,[440,270;440,315;455,315])
add_line(sys,[215,240;215,215;160,215;160,135;185,135])
add_line(sys,[425,140;435,200;445,240;460,255])
add_line(sys,[225,30;175,45])
add_line(sys,[160,135;160,115;185,115])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
