function [ret,x0,str]=sugmodel(t,x,u,flag);
%SUGMODEL	is the M-file description of the SIMULINK system named SUGMODEL.
%	The block-diagram can be displayed by typing: SUGMODEL.
%
%	SYS=SUGMODEL(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SUGMODEL to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SUGMODEL with a FLAG of zero:
%	[SIZES]=SUGMODEL([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[5,61,458,262])
     open_system(sys)
end;
set_param(sys,'algorithm',		'Euler')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'300')
set_param(sys,'Min step size',	'1')
set_param(sys,'Max step size',	'1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')

add_block('built-in/Scope',[sys,'/','Input1'])
set_param([sys,'/','Input1'],...
		'orientation',2,...
		'Vgain','1.876000',...
		'Hgain','10.000000',...
		'Vmax','2.000000',...
		'Hmax','20.000000',...
		'Window',[0,0,154,182],...
		'position',[105,113,135,147])


%     Subsystem  '"Ph" process'.

new_system([sys,'/','"Ph" process'])
set_param([sys,'/','"Ph" process'],'Location',[4,68,382,297])

add_block('built-in/Integrator',[sys,'/','"Ph" process/Integrator'])
set_param([sys,'/','"Ph" process/Integrator'],...
		'hide name',0,...
		'position',[185,50,220,90])

add_block('built-in/Gain',[sys,'/','"Ph" process/Gain'])
set_param([sys,'/','"Ph" process/Gain'],...
		'orientation',2,...
		'hide name',0,...
		'Gain','-3',...
		'position',[85,118,125,142])

add_block('built-in/Fcn',[sys,'/','"Ph" process/Fcn'])
set_param([sys,'/','"Ph" process/Fcn'],...
		'hide name',0,...
		'Expr','exp(u(1))',...
		'position',[75,65,115,85])

add_block('built-in/Product',[sys,'/','"Ph" process/Product'])
set_param([sys,'/','"Ph" process/Product'],...
		'hide name',0,...
		'position',[135,52,165,83])

add_block('built-in/Abs',[sys,'/','"Ph" process/Abs'])
set_param([sys,'/','"Ph" process/Abs'],...
		'orientation',2,...
		'hide name',0,...
		'position',[165,115,195,145])

add_block('built-in/Inport',[sys,'/','"Ph" process/in_1'])
set_param([sys,'/','"Ph" process/in_1'],...
		'position',[15,50,35,70])

add_block('built-in/Outport',[sys,'/','"Ph" process/out_1'])
set_param([sys,'/','"Ph" process/out_1'],...
		'position',[260,60,280,80])
add_line([sys,'/','"Ph" process'],[80,130;50,130;50,75;65,75])
add_line([sys,'/','"Ph" process'],[170,70;175,70])
add_line([sys,'/','"Ph" process'],[120,75;125,75])
add_line([sys,'/','"Ph" process'],[160,130;135,130])
add_line([sys,'/','"Ph" process'],[225,70;250,70])
add_line([sys,'/','"Ph" process'],[235,70;235,130;205,130])
add_line([sys,'/','"Ph" process'],[40,60;125,60])


%     Finished composite block '"Ph" process'.

set_param([sys,'/','"Ph" process'],...
		'position',[205,91,260,129])

add_block('built-in/Unit Delay',[sys,'/','Unit Delay'])
set_param([sys,'/','Unit Delay'],...
		'orientation',2,...
		'hide name',0,...
		'position',[200,6,235,34])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','3',...
		'position',[205,37,235,73])

add_block('built-in/S-function',[sys,'/','Sugeno'])
set_param([sys,'/','Sugeno'],...
		'function name','sfunsug',...
		'parameters','rls, mfs, p, def',...
		'Mask Display','SUGENO',...
		'Mask Type','Sugeno''s fuzzy inference')
set_param([sys,'/','Sugeno'],...
		'Mask Dialogue','Sugeno-Takagi inference|Premise matrix: |Membership functions matrix: |Consequent parameters: |Default output:',...
		'Mask Translate','rls = @1; mfs = @2; p = @3; def = @4;',...
		'Mask Help','')
set_param([sys,'/','Sugeno'],...
		'Mask Entries','[ones(7,1) (1:7)'']\/mfy\/p\/0\/',...
		'position',[255,39,330,71])

add_block('built-in/Transfer Fcn',[sys,'/','Filter'])
set_param([sys,'/','Filter'],...
		'Numerator','0.6',...
		'Denominator','[1 0.1]',...
		'position',[80,44,135,86])

add_block('built-in/Signal Generator',[sys,'/','Random'])
set_param([sys,'/','Random'],...
		'Peak','0.170000',...
		'Peak Range','5.000000',...
		'Freq','0.100000',...
		'Freq Range','50.000000',...
		'Wave','Rnd',...
		'Units','Rads',...
		'position',[10,48,55,82])


%     Subsystem  'White'.

new_system([sys,'/','White'])
set_param([sys,'/','White'],'Location',[4,68,278,261])

add_block('built-in/S-function',[sys,'/',['White/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['White/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunplot',...
		'parameters','figno,ax, color',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','White/x'])
set_param([sys,'/','White/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','White'],[90,65;120,65])
set_param([sys,'/','White'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','White'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter figure, plotting ranges and line type.|Figure:|Time range:|y-min:|y-max:|Line type (rgbw-:*):')
set_param([sys,'/','White'],...
		'Mask Translate','figno = @1; color = @5; ax = [0, @2, @3, @4];')
set_param([sys,'/','White'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Graph Scope block. Look at the m-file sfunplot.m to see how it works.')
set_param([sys,'/','White'],...
		'Mask Entries','1\/300\/-2\/2\/''w''\/')


%     Finished composite block 'White'.

set_param([sys,'/','White'],...
		'Drop Shadow',4,...
		'position',[375,36,405,74])


%     Subsystem  'Red'.

new_system([sys,'/','Red'])
set_param([sys,'/','Red'],'Location',[4,68,278,261])

add_block('built-in/Inport',[sys,'/','Red/x'])
set_param([sys,'/','Red/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-function',[sys,'/',['Red/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Red/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunplot',...
		'parameters','figno,ax, color',...
		'position',[130,55,180,75])
add_line([sys,'/','Red'],[90,65;120,65])
set_param([sys,'/','Red'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Red'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter figure, plotting ranges and line type.|Figure:|Time range:|y-min:|y-max:|Line type (rgbw-:*):')
set_param([sys,'/','Red'],...
		'Mask Translate','figno = @1; color = @5; ax = [0, @2, @3, @4];')
set_param([sys,'/','Red'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Graph Scope block. Look at the m-file sfunplot.m to see how it works.')
set_param([sys,'/','Red'],...
		'Mask Entries','1\/300\/-2\/2\/''r''\/')


%     Finished composite block 'Red'.

set_param([sys,'/','Red'],...
		'Drop Shadow',4,...
		'position',[325,91,355,129])
add_line(sys,[140,65;155,65;155,110;195,110])
add_line(sys,[335,55;365,55])
add_line(sys,[60,65;70,65])
add_line(sys,[265,110;315,110])
add_line(sys,[240,55;245,55])
add_line(sys,[195,20;175,20;175,55;195,55])
add_line(sys,[345,55;345,20;245,20])
add_line(sys,[155,65;195,65])
add_line(sys,[175,45;195,45])
add_line(sys,[155,110;155,130;145,130])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
