function ret = mfget(figno,property)
% MFGET Gets the parameters from membership functions editor.
%
% MFGET(FIGNO,PROPERTY)
%
% Available properties:
%       Mfs      - membership function definition matrix
%       Domain   - input domain (universe of discourse)
%       Input    - crisp input value
%       Grades   - membership grades of the current crisp input
%       Cmf      - number of the current membership function
%
% Property names are case insensitive. Get one property at a time.
%
% See also: MFSET

% (c) Robert Babuska, August 1993

% Argument check

if (nargin <  1), figno = gcf; property = 'mfs'; end;
if (nargin <  2), property = 'mfs'; end;
if ~any(figno == get(0,'Children')), ret = []; return; end;
if length(get(figno,'Children')) ~= 8, ret = []; return; end;

property = lower(property);
hc = get(figno,'UserData');
figa = get(figno,'CurrentAxes');

if strcmp(property,'mfs'),
    mf = get(figa,'UserData');
    ret = mf(:,1:5);
    return;
end;

if strcmp(property,'domain'),
    ret = get(hc(6),'UserData');
    return;
end;

if strcmp(property,'grades'),
    mf = get(figa,'UserData');
    ret = mgrade(get(hc(7),'Value'),mf(:,1:5));
    return;
end;

if strcmp(property,'input'),
    ret = get(hc(7),'Userdata');
    ret = ret(2);
    return;
end;

if strcmp(property,'cmf'),
    ret = hc(length(hc));
    return;
end;

