function c=or_lu(a,b)
%       C=OR_LU(A,B) Lukasiewicz union of two fuzzy sets A and B
%       defined as OR_LU(A,B) = min(Ax+Bx,1). Also called bold union or
%       bounded sum.
%
%       If A and B are both row or column vectors, then C
%       is also a row or column vector. If A is a column vector
%       and B a row vector, then a matrix C is returned,
%       representing the Cartesian product A + B, where +
%       is min(Ax+Bx,1).
%
%       C = OR_LU(A) calculates union of all rows in A.
%
%       See also OR, OR_ZA, OR_PR, OR_RE.

% (c) Robert Babuska, March 1993

if nargin == 2,
  [am,an] = size(a);
  [bm,bn] = size(b);
  if ( am > 1 & an == 1 & bn > 1 )
    a = a * ones(1,bn);
    if ( bm == 1 )
        b = ones(am,1) * b;
    end;
  end;
  c = min(a+b,1);
else
  c = min(sum(a),1);
end;

