function rls = rbfull(nlab)
% RBFULL generates a "complete" premise part of a rule-base,
% i.e. all possible combinations of input fuzzy sets (labels).
% Rule weights are equal to 1.
%
% RLS = RBFULL(NLAB)
%
% Inputs:       NLAB -  vector containing number of labels
%                       for each input, e.g. [2 3] for
%                       a premise part with two inputs, 2
%                       labels in the first and 3 in the second input

% Output:       RLS  -  Premise part of the rule-base, e.g.
%                       [1 1 1; 1 1 2; 1 1 3; 1 2 1; 1 2 2; 1 2 3]
%                       the above NLAB vector.
%
% See also TXT2RLS, RLS2TXT, DOFMIN, DOFPROD, DOFTN.

% (c) Robert Babuska, December 1993

nlab = fliplr(nlab(:).');               % make sure nlab is row vector
NN = prod(nlab);                        % calculate number of rules
nl = length(nlab);                      % number of inputs

c = [1 cumprod(nlab(nl:-1:2))];         % vector of divisors
NN1 = ones(NN,1);                       % aux
N = floor(((0 : NN-1)'*ones(1,nl))./(NN1*c(nl:-1:1)));   % divide
rls = fliplr(rem(N,NN1*nlab));
nlab = fliplr(nlab);

rls = rls + NN1*cumsum([1 nlab(1:nl-1)]);    % reminders
rls = [ones(NN,1) rls];

