function c=t_do(a,b,lambda)
%       C=T_DO(A,B,LAMBDA) The t-norm proposed by Dombi.
%       LAMBDA > 0
%
%       If A and B are both row or column vectors, then C
%       is also a row or column vector. If A is a column vector
%       and B a row vector, then a matrix C is returned,
%       representing the Cartesian product A x B.
%
%       T_DO(A,LAMBDA) calculates the t-norm between all rows in A.
%       In this case, LAMBDA can be a vector of parameters.
%
%       See also TNORM, T_DU, T_LA, T_YA, T_FR, T_HA, T_SK.

% (c) Robert Babuska, March 1993

am = size(a,1); bn = size(b,2);
if nargin == 3,
  if ( am > 1 & bn > 1 )
    a=a*ones(1,bn); b=ones(am,1)*b;
  end;
  c = (1 + ((a.^(-1) - 1).^lambda + ...
      (b.^(-1) - 1).^lambda).^(1/lambda)).^(-1);
else
    for j = length(b) : -1 : 1,
      c(j,:) = a(1,:);
      for i = 2 : am,
        c(j,:) = (1 + ((a(i,:).^(-1) - 1).^b(j) + ...
                 (c(j,:).^(-1) - 1).^b(j)).^(1/b(j))).^(-1);
      end;
    end;
end;
