function c=t_sk(a,b,p)
%       C=T_SK(A,B,P) The t-norm proposed by Schweizer and Sklar.
%
%       If A and B are both row or column vectors, then C
%       is also a row or column vector. If A is a column vector
%       and B a row vector, then a matrix C is returned,
%       representing the Cartesian product A x B.
%
%       T_SK(A,P) calculates the t-norm between all rows in A.
%       In this case, P can be a vector of parameters.
%
%       See also TNORM, T_DU, T_LA, T_YA, T_FR, T_HA, T_DO.

% (c) Robert Babuska, March 1993


am = size(a,1); bn = size(b,2);
if nargin == 3,
  if ( am > 1 & bn > 1 )
    a=a*ones(1,bn); b=ones(am,1)*b;
  end;
  a1 = 1 - a; b1 = 1 - b;
  c = 1 - (a1.^p + b1.^p - (a1.^p).*(b1.^p)).^(1/p);
else
    for j = length(b) : -1 : 1,
      c(j,:) = a(1,:);
      for i = 2 : am,
        a1 = 1 - a(i,:); b1 = 1 - c(j,:);
        c(j,:) = 1 - (a1.^b(j) + b1.^b(j) - (a1.^b(j)).*(b1.^b(j))).^(1/b(j));
      end;
    end;
end;
